@@ -4,7 +4,7 @@
 #   Thomas Liske <thomas@fiasko-nw.net>
 #
 # Copyright Holder:
-#   2013 - 2018 (C) Thomas Liske [http://fiasko-nw.net/~thomas/]
+#   2013 - 2022 (C) Thomas Liske [http://fiasko-nw.net/~thomas/]
 #
 # License:
 #   This program is free software; you can redistribute it and/or modify
@@ -30,9 +30,11 @@ use warnings;
 sub new {
     my $class = shift;
     my $debug = shift;
+    my $conf = shift;
 
     return bless {
 	debug => $debug,
+        conf => $conf,
     }, $class;
 }
 
